<?php
/**
 * @package Easyread
 */
namespace Erinc\Pages;

use \Erinc\Base\ErBaseController;
use \Erinc\Base\ErSplitParagraph;

require_once( EASYREAD__PLUGIN_DIR . 'erinc/base/ErBaseController.php' );
require_once( EASYREAD__PLUGIN_DIR . 'erinc/base/ErSplitParagraph.php' );
class Admin extends ErBaseController
{
    public function register(){
        if(is_admin()) {
	        add_action( 'admin_menu', array($this, 'er_add_settings_page') );
	        add_action( 'admin_init', array($this, 'er_register_settings') );
	        add_action( 'add_meta_boxes', array($this,'er_post_fields') );
	        add_filter("plugin_action_links_$this->plugin", array($this, 'setting_link'));
            add_action('save_post', array($this, 'er_post_settings'));
        } else{
            add_filter('the_content', array($this, 'er_filter'), 9999, 1);
            add_action('wp_enqueue_scripts', array($this, 'er_frontend_stylesheet'));
        }
    }

    /**
     * add style to frontend
     */
    function er_frontend_stylesheet() {
        wp_enqueue_style('easyreadstyle',$this->plugin_url.'/assets/easyRead.css');
    }

    /**
     * easyread filter content
     * @param $content
     * @return string|string[]|null
     */
    public function er_filter( $content ) {
        global $post;
        $masterPostSentenceCount = get_option('split_posts_by');
        $postSentenceCount = get_post_meta($post->ID,'easyread_plugin_post_count',true);
        $easyReadPostStatus = get_post_meta($post->ID,'easyread_disable_option',true);

        if ($post->post_type == 'post') {
	        $easyReadStatus = get_option('activate_post_toggle');
        } elseif ($post->post_type == 'page') {
	        $easyReadStatus = get_option('activate_page_toggle');
        }

        if (!empty($easyReadStatus)) {
            if(empty($easyReadPostStatus)) {
	            if ( ! empty( $postSentenceCount ) ) {
		            $content = ErSplitParagraph::er_splitPara( $postSentenceCount );
	            } elseif ( ! empty( $masterPostSentenceCount ) ) {
		            $content = ErSplitParagraph::er_splitPara( $masterPostSentenceCount );
	            }
            }
        }
	    $content = preg_replace( array(
		    '#<p>\s*<(div|aside|section|article|header|footer)#',
		    '#</(div|aside|section|article|header|footer)>\s*</p>#',
		    '#</(div|aside|section|article|header|footer)>\s*<br ?/?>#',
		    '#<(div|aside|section|article|header|footer)(.*?)>\s*</p>#',
		    '#<p>\s*</(div|aside|section|article|header|footer)#',
	    ), array(
		    '<$1',
		    '</$1>',
		    '</$1>',
		    '<$1$2>',
		    '</$1',
	    ), $content );

	    $content = force_balance_tags($content);
	    return preg_replace('#<p>(\s|&nbsp;)*+(<br\s*/*>)*(\s|&nbsp;)*</p>#i', '', $content);
    }

    /**
     * easyread setting page
     */
    public function er_add_settings_page() {
        add_options_page( 'Easyread settings page', 'Easyread', 'manage_options', 'easyread-plugin', array($this, 'er_render_plugin_settings_page') );
    }

    /**
     * easyread setting page render
     */
    public function er_render_plugin_settings_page() {
        require_once $this->plugin_path. '/templates/admin.php';
    }

    public function er_post_settings($post_id) {
        if(isset( $_POST['action'] )
            && isset( $_POST['easyread_nonce'] )) {
            // check if this isn't an auto save
            if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
                return;

            // now store data in custom fields based on checkboxes selected
            if (isset($_POST['easyread_plugin_post_count'])) {
                $easyread_post_count = sanitize_text_field($_POST['easyread_plugin_post_count']);
                update_post_meta($post_id, 'easyread_plugin_post_count', $easyread_post_count);
            } else {
                update_post_meta($post_id, 'easyread_plugin_post_count', 0);
            }
            if (isset($_POST['easyread_disable_option'])) {
                $easyread_post_disable = sanitize_text_field($_POST['easyread_disable_option']);
                update_post_meta($post_id, 'easyread_disable_option', $easyread_post_disable);
            } else {
                update_post_meta($post_id, 'easyread_disable_option', 0);
            }
        }
    }

    public function er_post_fields() {
    	$screen = array("post","page");
	    global $post;
	    if ($post->post_type == 'post') {
		    $easyReadStatus = get_option('activate_post_toggle');
	    } elseif ($post->post_type == 'page') {
		    $easyReadStatus = get_option('activate_page_toggle');
	    }
	    if($easyReadStatus) {
		    add_meta_box(
			    'my_meta_box_id',          // this is HTML id of the box on edit screen
			    'Easyread settings',    // title of the box
			    array(
				    $this,
				    'er_render_fields'
			    ),   // function to be called to display the checkboxes, see the function below
			    $screen,        // on which edit screen the box should appear
			    'side',      // part of page where the box should appear
			    'low'      // priority of the box
		    );
	    }
    }

    public function er_render_fields() {
        global $post;
	    $post_sentence_count = get_post_meta( $post->ID, 'easyread_plugin_post_count', true );
	    $post_disable_status = get_post_meta( $post->ID, 'easyread_disable_option', true );

	    // nonce field for security check, you can have the same
	    // nonce field for all your meta boxes of same plugin
	    wp_nonce_field( plugin_basename( __FILE__ ), 'easyread_nonce' );
	    $html = "<div class='easyread_disable_box'>";
	    $html .= "<span class='easyread_disable_checkbox'>Disable Easyread</span>";
	    $html .= "<input type='checkbox' name='easyread_disable_option' value='1' " . checked( 1, $post_disable_status, false ) . " />";
	    $html .= "</div><div class='easyread_post_count_box'>";
	    $html .= "<span class='easyread_count_input'>Split paragraphs every</span>";
	    $html .= "<input type='text' id='easyread_setting_count' onkeypress='return (event.charCode == 8 || event.charCode == 0 || event.charCode == 13) ? null : event.charCode >= 48 && event.charCode <= 57' name='easyread_plugin_post_count' type='text' value='" . $post_sentence_count . "' />";
        $html .= "<span> sentences</span>";
	    $html .= "</div>";
	    echo $html;
    }

    /**
     * easyread register settings
     */
    public function er_register_settings() {
        register_setting('easyread_plugin_options_group', 'activate_post_toggle');
        register_setting('easyread_plugin_options_group', 'activate_page_toggle');
        register_setting('easyread_plugin_options_group', 'split_posts_by');
        register_setting('easyread_plugin_options_group', 'split_pages_by');
    }

    /**
     * easyread setting page link
     * @param $links
     * @return mixed
     */
    public function setting_link($links){
        $setting_link = '<a href="options-general.php?page=easyread-plugin">Settings</a>';
        array_push($links,$setting_link);
        return $links;
    }
}